@@ -1,6 +1,6 @@
 """
 Easily install and update centralized pre-commit hooks and their configuration files
-in decentralized repositories
+in decentralized repositories.
 """
 
 from centralized_pre_commit_conf.install import install
