@@ -5,17 +5,21 @@ from colorama import Fore, init
 init()
 
 
+def echo(color: Fore, message: Union[Warning, str]) -> None:
+    print(f"{color}{message}{Fore.RESET}")
+
+
 def info(message: str) -> None:
-    print(f"{Fore.BLUE}{message}{Fore.RESET}")
+    echo(Fore.BLUE, message)
 
 
 def warn(message: Union[Warning, str]) -> None:
-    print(f"{Fore.YELLOW}{message}{Fore.RESET}")
+    echo(Fore.YELLOW, message)
 
 
 def error(message: str) -> None:
-    print(f"{Fore.RED}{message}{Fore.RESET}")
+    echo(Fore.RED, message)
 
 
 def success(message: str) -> None:
-    print(f"{Fore.GREEN}{message}{Fore.RESET}")
+    echo(Fore.GREEN, message)
